==> bpp_iplweb-1.0.31.dev2-py3-none-any.whl: bpp/tests/test_selenium/test_admin/test_podpowiedzi_dyscyplin.py <==
import pytest
from django.urls import reverse

from bpp.models import Autor_Dyscyplina
from bpp.tests import select_select2_autocomplete
from django_bpp.selenium_util import wait_for


@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_dwie(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2):
    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1,
                                    subdyscyplina_naukowa=dyscyplina2)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    preauth_admin_browser.execute_script("""
    document.getElementsByClassName("grp-add-handler")[0].scrollIntoView();
    window.scrollBy(0, 400);
    """)

    preauth_admin_browser.find_by_css(".grp-add-handler").first.click()
    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert sel.value == "---------"


@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_jedna_uczelnia_podpowiada(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2, uczelnia):
    uczelnia.podpowiadaj_dyscypliny = True
    uczelnia.save()

    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    preauth_admin_browser.execute_script("""
    document.getElementsByClassName("grp-add-handler")[0].scrollIntoView();
    window.scrollBy(0, 500)
    """)

    preauth_admin_browser.find_by_css(".grp-add-handler").first.click()
    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert int(sel.value) == dyscyplina1.pk


@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_jedna_uczelnia_nie_podpowiada(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2, uczelnia):
    uczelnia.podpowiadaj_dyscypliny = False
    uczelnia.save()

    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    preauth_admin_browser.execute_script("""
    document.getElementsByClassName("grp-add-handler")[0].scrollIntoView();
    window.scrollBy(0, 500);
    """)

    preauth_admin_browser.find_by_css(".grp-add-handler").first.click()
    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert sel.value == "---------"

==> bpp_iplweb-201910.3a0-py3-none-any.whl: bpp/tests/test_selenium/test_admin/test_podpowiedzi_dyscyplin.py <==
import pytest
from django.urls import reverse
from selenium.common.exceptions import ElementClickInterceptedException

from bpp.models import Autor_Dyscyplina
from bpp.tests import select_select2_autocomplete
from django_bpp.selenium_util import wait_for


def scroll_until_handler_clicked_successfully(browser, handler="grp-add-handler"):
    browser.execute_script('document.getElementsByClassName("%s")[0].scrollIntoView();' % handler)
    no_tries = 0
    while no_tries < 20:
        try:
            browser.find_by_css(".grp-add-handler").first.click()
            break
        except ElementClickInterceptedException:
            browser.execute_script("window.scrollBy(0, 25)")
        no_tries += 1

@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_dwie(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2):
    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1,
                                    subdyscyplina_naukowa=dyscyplina2)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    scroll_until_handler_clicked_successfully(preauth_admin_browser)

    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert sel.value == "---------"


@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_jedna_uczelnia_podpowiada(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2, uczelnia):
    uczelnia.podpowiadaj_dyscypliny = True
    uczelnia.save()

    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    scroll_until_handler_clicked_successfully(preauth_admin_browser)

    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert int(sel.value) == dyscyplina1.pk


@pytest.mark.parametrize(
    "url", ["wydawnictwo_ciagle", "wydawnictwo_zwarte"]
)
def test_podpowiedzi_dyscyplin_autor_ma_jedna_uczelnia_nie_podpowiada(
        url, live_server, preauth_admin_browser, autor_jan_kowalski, dyscyplina1, dyscyplina2, uczelnia):
    uczelnia.podpowiadaj_dyscypliny = False
    uczelnia.save()

    Autor_Dyscyplina.objects.create(rok=2018, autor=autor_jan_kowalski, dyscyplina_naukowa=dyscyplina1)
    url = reverse("admin:bpp_%s_add" % url)
    preauth_admin_browser.visit(live_server + url)

    preauth_admin_browser.type("rok", "2018")

    scroll_until_handler_clicked_successfully(preauth_admin_browser)

    wait_for(
        lambda: preauth_admin_browser.find_by_id("id_autorzy_set-0-autor")
    )
    select_select2_autocomplete(
        preauth_admin_browser,
        "id_autorzy_set-0-autor",
        "KOWALSKI"
    )

    sel = preauth_admin_browser.find_by_id("id_autorzy_set-0-dyscyplina_naukowa")
    assert sel.value == "---------"
